Module: Google::Cloud::ServiceUsage
- Defined in:
- lib/google/cloud/service_usage.rb,
lib/google/cloud/service_usage/version.rb
Constant Summary collapse
- VERSION =
"0.1.0"
Class Method Summary collapse
-
.configure {|::Google::Cloud.configure.service_usage| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-service_usage library.
-
.service_usage(version: :v1, &block) ⇒ ServiceUsage::Client
Create a new client object for ServiceUsage.
Class Method Details
.configure {|::Google::Cloud.configure.service_usage| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-service_usage library.
The following configuration parameters are supported:
credentials(type:String, Hash, Google::Auth::Credentials) - The path to the keyfile as a String, the contents of the keyfile as a Hash, or a Google::Auth::Credentials object.lib_name(type:String) - The library name as recorded in instrumentation and logging.lib_version(type:String) - The library version as recorded in instrumentation and logging.interceptors(type:Array<GRPC::ClientInterceptor>) - An array of interceptors that are run before calls are executed.timeout(type:Numeric) - Default timeout in seconds.metadata(type:Hash{Symbol=>String}) - Additional gRPC headers to be sent with the call.-
retry_policy(type:Hash) - The retry policy. The value is a hash with the following keys:* `:initial_delay` (*type:* `Numeric`) - The initial delay in seconds. * `:max_delay` (*type:* `Numeric`) - The max delay in seconds. * `:multiplier` (*type:* `Numeric`) - The incremental backoff multiplier. * `:retry_codes` (*type:* `Array<String>`) - The error codes that should trigger a retry.
109 110 111 112 113 |
# File 'lib/google/cloud/service_usage.rb', line 109 def self.configure yield ::Google::Cloud.configure.service_usage if block_given? ::Google::Cloud.configure.service_usage end |
.service_usage(version: :v1, &block) ⇒ ServiceUsage::Client
Create a new client object for ServiceUsage.
By default, this returns an instance of
Google::Cloud::ServiceUsage::V1::ServiceUsage::Client
for version V1 of the API.
However, you can specify specify a different API version by passing it in the
version parameter. If the ServiceUsage service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
About ServiceUsage
Enables services that service consumers want to use on Google Cloud Platform, lists the available or enabled services, or disables services that service consumers no longer use.
70 71 72 73 74 75 76 77 78 79 |
# File 'lib/google/cloud/service_usage.rb', line 70 def self.service_usage version: :v1, &block require "google/cloud/service_usage/#{version.to_s.downcase}" package_name = Google::Cloud::ServiceUsage .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first package_module = Google::Cloud::ServiceUsage.const_get package_name package_module.const_get(:ServiceUsage).const_get(:Client).new(&block) end |